@@ -1,6 +1,6 @@
 module Main where
 
-import Build_doctests (flags, pkgs, module_sources)
+import Build_doctests (flags, module_sources, pkgs)
 import Data.Foldable (traverse_)
 import Test.DocTest (doctest)
 
